@@ -14,6 +14,9 @@
  * limitations under the License.
  * ************************************************************************/
 
+#ifdef _MSC_VER
+#pragma warning(disable : 4996)
+#endif
 
 #pragma once
 #if !defined( OPENCL_MISC_H )
