@@ -74,14 +74,15 @@ int main( void )
 
     /* print input array just using the
      * indices to fill the array with data */
-    printf("\nPerforming fft on an two dimensional array of size N0 x N1 : %u x %u\n", (unsigned long)N0, (unsigned long)N1);
+    printf("\nPerforming fft on an two dimensional array of size N0 x N1 : %lu x %lu\n", (unsigned long)N0, (unsigned long)N1);
 	size_t i, j;
+
     i = j = 0;
     for (i=0; i<N0; ++i) {
         for (j=0; j<N1; ++j) {
             float x = 0.5f;
             float y = 0.5f;
-			size_t idx = 2*(j+i*N0);
+            size_t idx = 2*(j+i*N1);
             X[idx] = x;
             X[idx+1] = y;
             printf("(%f, %f) ", x, y);
@@ -119,7 +120,7 @@ int main( void )
     i = j = 0;
     for (i=0; i<N0; ++i) {
         for (j=0; j<N1; ++j) {
-			size_t idx = 2*(j+i*N0);
+            size_t idx = 2*(j+i*N1);
             printf("(%f, %f) ", X[idx], X[idx+1]);
         }
         printf("\n");
